@@ -1,28 +1,29 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="es" sourcelanguage="">
-<context encoding="UTF-8">
+<!DOCTYPE TS>
+<TS version="2.1" language="es">
+<context>
     <name>Dialog</name>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Préférences de pyMecaVideo</source>
         <translation type="obsolete">Preferencias de pyMecaVideo</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Échelle des vitesses (px pour 1m/s)</source>
         <translation type="obsolete">Escala de velocidades (px para 1m/s)</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Vitesses affichées</source>
         <translation type="obsolete">Velocidades mostradas</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Afficheur vidéo</source>
         <translation type="obsolete">Display video</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Niveau de verbosité (débogage)</source>
         <translation type="obsolete">Nivel de debug</translation>
@@ -32,7 +33,7 @@
     <name>Label_Echelle</name>
     <message>
         <location filename="." line="144"/>
-        <source>Choisir le nombre de points puis &quot;D&#xc3;&#xa9;marrer l&apos;acquisition&quot; </source>
+        <source>Choisir le nombre de points puis &quot;DÃ©marrer l&apos;acquisition&quot; </source>
         <translation type="obsolete">Escojer el número de puntos y &quot;iniciar la acquisición&quot;</translation>
     </message>
 </context>
@@ -40,7 +41,7 @@
     <name>StartQT4</name>
     <message>
         <location filename="pymecavideo.py" line="379"/>
-        <source>ind&#xc3;&#xa9;f.</source>
+        <source>indÃ©f.</source>
         <translation type="obsolete">indéf.</translation>
     </message>
     <message>
@@ -50,54 +51,54 @@
     </message>
     <message>
         <location filename="pymecavideo.py" line="1041"/>
-        <source>temps en seconde, positions en m&#xc3;&#xa8;tre</source>
+        <source>temps en seconde, positions en mÃ¨tre</source>
         <translation type="obsolete">tiempo en segundos, posición en metros</translation>
     </message>
     <message>
         <location filename="." line="144"/>
-        <source>point N&#xc2;&#xb0; </source>
+        <source>point NÂ° </source>
         <translation type="obsolete">Point N° </translation>
     </message>
     <message>
         <location filename="." line="144"/>
-        <source>Cliquer sur le point N&#xc2;&#xb0;%d</source>
+        <source>Cliquer sur le point NÂ°%d</source>
         <translation type="obsolete">Clic en el punto N° :</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1518"/>
-        <source>D&#xc3;&#xa9;finir une &#xc3;&#xa9;chelle</source>
+        <source>DÃ©finir une Ã©chelle</source>
         <translation type="obsolete">Definir la escala</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1518"/>
-        <source>Quelle est la longueur en m&#xc3;&#xa8;tre de votre &#xc3;&#xa9;talon sur l&apos;image ?</source>
+        <source>Quelle est la longueur en mÃ¨tre de votre Ã©talon sur l&apos;image ?</source>
         <translation type="obsolete">¿Cuál es el tamaño , en metros de su calibrador en la imagen?</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1536"/>
-        <source> Merci d&apos;indiquer une &#xc3;&#xa9;chelle valable</source>
+        <source> Merci d&apos;indiquer une Ã©chelle valable</source>
         <translation type="obsolete">Usted tiene que dar una escala válida</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1592"/>
-        <source>Les donn&#xc3;&#xa9;es seront perdues</source>
+        <source>Les donnÃ©es seront perdues</source>
         <translation type="obsolete">Los datos serán perdidos</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1592"/>
-        <source>Votre travail n&apos;a pas &#xc3;&#xa9;t&#xc3;&#xa9; sauvegard&#xc3;&#xa9;
+        <source>Votre travail n&apos;a pas Ã©tÃ© sauvegardÃ©
 Voulez-vous les sauvegarder ?</source>
         <translation type="obsolete">Su trabajo no ha sido guardado.
 ¿Quiere Usted guardarlo ahora?</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1614"/>
-        <source>Vous avez atteint le d&#xc3;&#xa9;but de la vid&#xc3;&#xa9;o</source>
+        <source>Vous avez atteint le dÃ©but de la vidÃ©o</source>
         <translation type="obsolete">Usted alcanzó el principio del video</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1650"/>
-        <source>Ouvrir une vid&#xc3;&#xa9;o</source>
+        <source>Ouvrir une vidÃ©o</source>
         <translation type="obsolete">Abrir un video</translation>
     </message>
     <message>
@@ -107,18 +108,18 @@ Voulez-vous les sauvegarder ?</source>
     </message>
     <message>
         <location filename="." line="144"/>
-        <source>Le nom de votre fichier contient des caract&#xc3;&#xa8;res accentu&#xc3;&#xa9;s ou des espaces.
+        <source>Le nom de votre fichier contient des caractÃ¨res accentuÃ©s ou des espaces.
  Merci de bien vouloir le renommer avant de continuer</source>
         <translation type="obsolete">El nombre de su archivo contiene caracteres con acentos o espacios. Por favor retirenlos antes de seguir.</translation>
     </message>
     <message>
         <location filename="pymecavideo.py" line="1677"/>
-        <source>Veuillez choisir une image et d&#xc3;&#xa9;finir l&apos;&#xc3;&#xa9;chelle</source>
+        <source>Veuillez choisir une image et dÃ©finir l&apos;Ã©chelle</source>
         <translation type="obsolete">Usted debe escojer una imagen y definir la escala</translation>
     </message>
     <message>
         <location filename="." line="144"/>
-        <source>D&#xc3;&#xa9;sol&#xc3;&#xa9; pas de fichier d&apos;aide pour ce langage %s.</source>
+        <source>DÃ©solÃ© pas de fichier d&apos;aide pour ce langage %s.</source>
         <translation type="obsolete">Lo siento, no hay archivo de ayuda para este idioma</translation>
     </message>
     <message>
@@ -133,49 +134,49 @@ Voulez-vous les sauvegarder ?</source>
     </message>
     <message>
         <location filename="." line="144"/>
-        <source>point N&#xc2;&#xb0;</source>
+        <source>point NÂ°</source>
         <translation type="obsolete">punto N°</translation>
     </message>
 </context>
 <context>
     <name>pymecavideo</name>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="37"/>
         <source>PyMecaVideo, analyse mécanique des vidéos</source>
         <translation type="obsolete">PyMecaVideo, análisis mecánica de los videos</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="86"/>
         <source>Acquisition des données</source>
         <translation type="obsolete">Acquisición de datos</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="189"/>
         <source>Pas de vidéos chargées</source>
         <translation type="obsolete">No se ha cargado ningún video</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Bienvenue sur pymeca vidéo, pas d&apos;images chargée</source>
         <translation type="obsolete">Bienvenidos en pymecavideo, no se ha cargado ningún video</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="551"/>
         <source>Définir l&apos;échelle</source>
         <translation type="obsolete">Definir la escala</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="229"/>
         <source>Image n°</source>
         <translation type="obsolete">Imagen n°</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Nombre de points à étudier</source>
         <translation type="obsolete">Numero de puntos a estudiar</translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="371"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="370"/>
         <source>indéf.</source>
         <translation>indef.</translation>
     </message>
@@ -184,22 +185,22 @@ Voulez-vous les sauvegarder ?</source>
         <source>px/m</source>
         <translation type="obsolete">px/m</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Démarrer l&apos;acquisition</source>
         <translation type="obsolete">Iniciar la acquisiciónf</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="535"/>
         <source>Tout réinitialiser</source>
         <translation type="obsolete">Reinicializar a todo</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>efface le point précédent</source>
         <translation type="obsolete">elimina el punto precedente</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="455"/>
         <source>rétablit le point suivant</source>
         <translation type="obsolete">recupera el punto precedente</translation>
@@ -209,12 +210,12 @@ Voulez-vous les sauvegarder ?</source>
         <source>trajectoires et mesures</source>
         <translation type="obsolete">trayectorias y medidas</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Origine du référentiel :</source>
         <translation type="obsolete">Origen del referencial</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Vidéo calculée</source>
         <translation type="obsolete">Video calculado</translation>
@@ -239,7 +240,7 @@ Voulez-vous les sauvegarder ?</source>
         <source>ralenti /8</source>
         <translation type="obsolete">velocidad 1/8</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Échelle de vitesses :</source>
         <translation type="obsolete">Escala de velocidades</translation>
@@ -249,7 +250,7 @@ Voulez-vous les sauvegarder ?</source>
         <source>px pour 1 m/s</source>
         <translation type="obsolete">px para 1 m/s</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="../../src/pymecavideo_mini.ui" line="972"/>
         <source>Coordonnées</source>
         <translation type="obsolete">Coordenadas</translation>
@@ -269,13 +270,13 @@ Voulez-vous les sauvegarder ?</source>
         <source>Aide</source>
         <translation type="obsolete">Ayuda</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Édition</source>
         <translation type="obsolete">Edicion</translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="1931"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="2011"/>
         <source>Ouvrir une vidéo</source>
         <translation type="unfinished">Abrir un video</translation>
     </message>
@@ -294,22 +295,22 @@ Voulez-vous les sauvegarder ?</source>
         <source>Quitter</source>
         <translation type="obsolete">Salir</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Enregistrer les données</source>
         <translation type="obsolete">Guardar datos</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>À propos</source>
         <translation type="obsolete">About</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Rouvrir un fichier mecavidéo</source>
         <translation type="obsolete">Reabrir un archivo mecavideo</translation>
     </message>
-    <message encoding="UTF-8">
+    <message>
         <location filename="." line="144"/>
         <source>Préférences</source>
         <translation type="obsolete">Preferencias</translation>
@@ -320,80 +321,80 @@ Voulez-vous les sauvegarder ?</source>
         <translation type="obsolete">copiar</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1482"/>
+        <location filename="../../src/pymecavideo.py" line="1562"/>
         <source>Choisir ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="297"/>
-        <source>ind&#xc3;&#xa9;f</source>
+        <location filename="../../src/pymecavideo.py" line="296"/>
+        <source>indÃ©f</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="920"/>
+        <location filename="../../src/pymecavideo.py" line="994"/>
         <source>Ouvrir un projet Pymecavideo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="920"/>
+        <location filename="../../src/pymecavideo.py" line="994"/>
         <source>fichiers pymecavideo(*.csv)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1227"/>
-        <source>temps en seconde, positions en m&#xc3;&#xa8;tre</source>
+        <location filename="../../src/pymecavideo.py" line="1300"/>
+        <source>temps en seconde, positions en mÃ¨tre</source>
         <translation type="unfinished">tiempo en segundos, posición en metros</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1585"/>
-        <source>Vous avez atteint la fin de la vid&#xc3;&#xa9;o</source>
+        <location filename="../../src/pymecavideo.py" line="1665"/>
+        <source>Vous avez atteint la fin de la vidÃ©o</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1791"/>
-        <source>D&#xc3;&#xa9;finir une &#xc3;&#xa9;chelle</source>
+        <location filename="../../src/pymecavideo.py" line="1871"/>
+        <source>DÃ©finir une Ã©chelle</source>
         <translation type="unfinished">Definir la escala</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1791"/>
-        <source>Quelle est la longueur en m&#xc3;&#xa8;tre de votre &#xc3;&#xa9;talon sur l&apos;image ?</source>
+        <location filename="../../src/pymecavideo.py" line="1871"/>
+        <source>Quelle est la longueur en mÃ¨tre de votre Ã©talon sur l&apos;image ?</source>
         <translation type="unfinished">¿Cuál es el tamaño , en metros de su calibrador en la imagen?</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1812"/>
-        <source> Merci d&apos;indiquer une &#xc3;&#xa9;chelle valable</source>
+        <location filename="../../src/pymecavideo.py" line="1892"/>
+        <source> Merci d&apos;indiquer une Ã©chelle valable</source>
         <translation type="unfinished">Usted tiene que dar una escala válida</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1868"/>
-        <source>Les donn&#xc3;&#xa9;es seront perdues</source>
+        <location filename="../../src/pymecavideo.py" line="1948"/>
+        <source>Les donnÃ©es seront perdues</source>
         <translation type="unfinished">Los datos serán perdidos</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1868"/>
-        <source>Votre travail n&apos;a pas &#xc3;&#xa9;t&#xc3;&#xa9; sauvegard&#xc3;&#xa9;
+        <location filename="../../src/pymecavideo.py" line="1948"/>
+        <source>Votre travail n&apos;a pas Ã©tÃ© sauvegardÃ©
 Voulez-vous les sauvegarder ?</source>
         <translation type="unfinished">Su trabajo no ha sido guardado.
 ¿Quiere Usted guardarlo ahora?</translation>
     </message>
     <message>
         <location filename="../../src/pymecavideo.py" line="1782"/>
-        <source>Vous avez atteint le d&#xc3;&#xa9;but de la vid&#xc3;&#xa9;o</source>
+        <source>Vous avez atteint le dÃ©but de la vidÃ©o</source>
         <translation type="obsolete">Usted alcanzó el principio del video</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1926"/>
+        <location filename="../../src/pymecavideo.py" line="2006"/>
         <source>Nom de fichier non conforme</source>
         <translation type="unfinished">Nombre de archivo no valido</translation>
     </message>
     <message>
         <location filename="../../src/pymecavideo.py" line="1862"/>
-        <source>Veuillez choisir une image et d&#xc3;&#xa9;finir l&apos;&#xc3;&#xa9;chelle</source>
+        <source>Veuillez choisir une image et dÃ©finir l&apos;Ã©chelle</source>
         <translation type="obsolete">Usted debe escojer una imagen y definir la escala</translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1912"/>
-        <source>fichiers vid&#xc3;&#xa9;os ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</source>
+        <location filename="../../src/pymecavideo.py" line="1992"/>
+        <source>fichiers vidÃ©os ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -407,67 +408,72 @@ Voulez-vous les sauvegarder ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1320"/>
-        <source>Veuillez s&#xc3;&#xa9;lectionner un cadre autour de(s) l&apos;objet(s) que vous voulez suivre.
-Vous pouvez arr&#xc3;&#xaa;ter &#xc3;&#xa0; tous moments la capture en appuyant sur le bouton</source>
+        <location filename="../../src/pymecavideo.py" line="1393"/>
+        <source>Veuillez sÃ©lectionner un cadre autour de(s) l&apos;objet(s) que vous voulez suivre.
+Vous pouvez arrÃªter Ã&#xa0; tous moments la capture en appuyant sur le bouton</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1926"/>
-        <source>Le nom de votre fichier contient des caract&#xc3;&#xa8;res accentu&#xc3;&#xa9;s ou des espaces.
+        <location filename="../../src/pymecavideo.py" line="2006"/>
+        <source>Le nom de votre fichier contient des caractÃ¨res accentuÃ©s ou des espaces.
 Merci de bien vouloir le renommer avant de continuer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="344"/>
+        <location filename="../../src/pymecavideo.py" line="343"/>
         <source>NON DISPO : {0}</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="1298"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="1371"/>
         <source>point N° {0}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1513"/>
+        <location filename="../../src/pymecavideo.py" line="1593"/>
         <source>Evolution de l&apos;abscisse du point {0}</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="1513"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="1593"/>
         <source>Evolution de l&apos;ordonnée du point {0}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/pymecavideo.py" line="1513"/>
+        <location filename="../../src/pymecavideo.py" line="1593"/>
         <source>Evolution de la vitesse du point {0}</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="1560"/>
-        <source>Pointage des positions : cliquer sur le point N° {0}</source>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="1640"/>
+        <source>Pointage des positions&#xa0;: cliquer sur le point N° {0}</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="2009"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="2088"/>
         <source>Désolé pas de fichier d&apos;aide pour le langage {0}.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="1896"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="1976"/>
         <source>fichiers vidéos (*.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="1974"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="2054"/>
         <source>Veuillez choisir une image (et définir l&apos;échelle)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../../src/pymecavideo.py" line="2064"/>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="2143"/>
         <source>Pymecavideo n&apos;arrive pas à lire l&apos;image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../src/pymecavideo.py" line="882"/>
+        <source>Fichier Python créé</source>
+        <translation>Creacion del archivo Python</translation>
+    </message>
 </context>
 <context>
     <name>self.app</name>
@@ -478,7 +484,7 @@ Merci de bien vouloir le renommer avant de continuer</source>
     </message>
     <message>
         <location filename="../../src/echelle.py" line="159"/>
-        <source>Choisir le nombre de points puis &#xc2;&#xab;&#xc2;&#xa0;D&#xc3;&#xa9;marrer l&apos;acquisition&#xc2;&#xa0;&#xc2;&#xbb; </source>
+        <source>Choisir le nombre de points puis Â«Â&#xa0;DÃ©marrer l&apos;acquisitionÂ&#xa0;Â» </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -487,22 +493,22 @@ Merci de bien vouloir le renommer avant de continuer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/preferences.py" line="48"/>
+        <location filename="../../src/preferences.py" line="47"/>
         <source>Proximite de la souris {0}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/preferences.py" line="49"/>
+        <location filename="../../src/preferences.py" line="48"/>
         <source>; derniere video {0}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/preferences.py" line="50"/>
+        <location filename="../../src/preferences.py" line="49"/>
         <source>; videoDir {0}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/cadreur.py" line="138"/>
+        <location filename="../../src/cadreur.py" line="137"/>
         <source>Choisir le ralenti</source>
         <translation type="unfinished"></translation>
     </message>
